@@ -9,6 +9,6 @@ if __name__ == "__main__":
         # "scraparser" package is discoverable.
         sys.path.insert(0, os.path.dirname(os.path.dirname(__file__)))
 
-    from scraparser import cli
+    from .cli import entry_point
     #  pylint: disable=no-value-for-parameter,unexpected-keyword-arg
-    cli(obj={})
+    entry_point(obj={})
